# layint-scan-api
Layered Insight Scan performs static vulnerability analysis, license and package compliance.  You can find out more about Scan at http://layeredinsight.com.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 0.9.6
- Package version: 0.9.6
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/layeredinsight/layint_scan_api_python.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/layeredinsight/layint_scan_api_python.git`)

Then import the package:
```python
import layint_scan_api 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import layint_scan_api
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import layint_scan_api
from layint_scan_api.rest import ApiException
from pprint import pprint

# Configure API key authorization: ApiKey
layint_scan_api.configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# layint_scan_api.configuration.api_key_prefix['Authorization'] = 'Bearer'
# create an instance of the API class
api_instance = layint_scan_api.AnalyticsApi()
cve_search_field = layint_scan_api.CveSearchField() # CveSearchField | 

try:
    # Searches image scan results for specified CVE ID
    api_response = api_instance.cve_search(cve_search_field)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AnalyticsApi->cve_search: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://scan-api.layeredinsight.com/V0.0.1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AnalyticsApi* | [**cve_search**](docs/AnalyticsApi.md#cve_search) | **POST** /CveSearch | Searches image scan results for specified CVE ID
*AnalyticsApi* | [**get_stats**](docs/AnalyticsApi.md#get_stats) | **GET** /Stats | Gets vulnerability statistics for user&#39;s images
*AnalyticsApi* | [**package_search**](docs/AnalyticsApi.md#package_search) | **POST** /PackageSearch | Searches for images with a specified software package
*AnalyticsApi* | [**top_cves**](docs/AnalyticsApi.md#top_cves) | **POST** /TopCves | Returns a list of most common/severe vulnerabilities present in a users images
*AnalyticsApi* | [**top_vuln_images**](docs/AnalyticsApi.md#top_vuln_images) | **POST** /TopVulnImages | Returns a list of most vulnerable images
*AuthenticationApi* | [**login**](docs/AuthenticationApi.md#login) | **POST** /Login | Processes local login request
*AuthenticationApi* | [**token_request**](docs/AuthenticationApi.md#token_request) | **POST** /TokenRequest | Returns a session token for a oauth2 token
*ClairApi* | [**clair_update**](docs/ClairApi.md#clair_update) | **POST** /ClairUpdate | Notify user(s) of vulnerability update from clair notification
*ClairApi* | [**get_clair_updates**](docs/ClairApi.md#get_clair_updates) | **GET** /Updates | Returns date/time estimation when clair updates will be done
*ComplianceApi* | [**add_policy**](docs/ComplianceApi.md#add_policy) | **POST** /Policies | Add a new policy
*ComplianceApi* | [**add_policy_rule**](docs/ComplianceApi.md#add_policy_rule) | **POST** /Rules | Add a new policy rule
*ComplianceApi* | [**delete_policy**](docs/ComplianceApi.md#delete_policy) | **DELETE** /Policies/{policyID} | Delete compliance policy
*ComplianceApi* | [**delete_policy_rule**](docs/ComplianceApi.md#delete_policy_rule) | **DELETE** /Rules/{ruleID} | Delete compliance policy rule
*ComplianceApi* | [**get_policies**](docs/ComplianceApi.md#get_policies) | **GET** /Policies | List all compliance policies available to the user
*ComplianceApi* | [**get_policy**](docs/ComplianceApi.md#get_policy) | **GET** /Policies/{policyID} | Get compliance policy
*ComplianceApi* | [**get_policy_rule**](docs/ComplianceApi.md#get_policy_rule) | **GET** /Rules/{ruleID} | Get compliance policy rule
*ComplianceApi* | [**get_policy_rules**](docs/ComplianceApi.md#get_policy_rules) | **GET** /Rules | List all compliance rules available to the user
*ComplianceApi* | [**update_policy**](docs/ComplianceApi.md#update_policy) | **POST** /Policies/{policyID} | Update policy
*ComplianceApi* | [**update_policy_rule**](docs/ComplianceApi.md#update_policy_rule) | **POST** /Rules/{ruleID} | Update policy rule
*ImagesApi* | [**add_image**](docs/ImagesApi.md#add_image) | **POST** /Images | Submit an image name for scanning
*ImagesApi* | [**add_image_tags**](docs/ImagesApi.md#add_image_tags) | **POST** /Images/{imageID} | Add tags to image
*ImagesApi* | [**delete_image**](docs/ImagesApi.md#delete_image) | **DELETE** /Images/{imageID} | Delete specified image
*ImagesApi* | [**get_image**](docs/ImagesApi.md#get_image) | **GET** /Images/{imageID} | Get image details
*ImagesApi* | [**get_image_compliance**](docs/ImagesApi.md#get_image_compliance) | **GET** /Images/{imageID}/Compliance | Get compliance report for specified image
*ImagesApi* | [**get_image_licenses**](docs/ImagesApi.md#get_image_licenses) | **GET** /Images/{imageID}/Licenses | Find software licenses for the components making up the image
*ImagesApi* | [**get_image_log**](docs/ImagesApi.md#get_image_log) | **GET** /Images/{imageID}/Logs/{logID} | Get a log for an image
*ImagesApi* | [**get_image_logs**](docs/ImagesApi.md#get_image_logs) | **GET** /Images/{imageID}/Logs | Get logs for an image
*ImagesApi* | [**get_image_scan**](docs/ImagesApi.md#get_image_scan) | **GET** /Images/{imageID}/Scans/{scanID} | Get scan data for specific scan for specified image
*ImagesApi* | [**get_image_scans**](docs/ImagesApi.md#get_image_scans) | **GET** /Images/{imageID}/Scans | Get all scan data for specified image
*ImagesApi* | [**get_images**](docs/ImagesApi.md#get_images) | **GET** /Images | Get list of scanned images
*ImagesApi* | [**is_image_compliant**](docs/ImagesApi.md#is_image_compliant) | **GET** /Images/{imageID}/IsCompliant | Determines if specified image is in compliance with policies applied to image
*LicenseApi* | [**license_get**](docs/LicenseApi.md#license_get) | **GET** /License | Get application license information
*LicenseApi* | [**update_license**](docs/LicenseApi.md#update_license) | **POST** /License | Add or update application license
*RegistryApi* | [**add_ecr_creds**](docs/RegistryApi.md#add_ecr_creds) | **POST** /EcrCreds | Add credentials for AWS ECR
*RegistryApi* | [**add_registry**](docs/RegistryApi.md#add_registry) | **POST** /Registry | Add a new registry
*RegistryApi* | [**delete_registry**](docs/RegistryApi.md#delete_registry) | **DELETE** /Registry/{registryId} | Deletes a registry
*RegistryApi* | [**get_registries**](docs/RegistryApi.md#get_registries) | **GET** /Registry | List all registries available to the user
*RegistryApi* | [**get_registry_by_id**](docs/RegistryApi.md#get_registry_by_id) | **GET** /Registry/{registryId} | Find registry by ID
*RegistryApi* | [**update_registry**](docs/RegistryApi.md#update_registry) | **POST** /Registry/{registryId} | Updates a registry with form data
*TagsApi* | [**add_tag**](docs/TagsApi.md#add_tag) | **POST** /Tags | Add a tag
*TagsApi* | [**delete_tag**](docs/TagsApi.md#delete_tag) | **DELETE** /Tags/{tagID} | Delete a tag by ID
*TagsApi* | [**get_tag**](docs/TagsApi.md#get_tag) | **GET** /Tags/{tagID} | Get a tag by ID
*TagsApi* | [**get_tags**](docs/TagsApi.md#get_tags) | **GET** /Tags | List all tags


## Documentation For Models

 - [BadRequestError](docs/BadRequestError.md)
 - [ClairData](docs/ClairData.md)
 - [ClairFeature](docs/ClairFeature.md)
 - [ClairLayer](docs/ClairLayer.md)
 - [ClairUpdateNotification](docs/ClairUpdateNotification.md)
 - [ClairUpdateRequest](docs/ClairUpdateRequest.md)
 - [ClairVulnerability](docs/ClairVulnerability.md)
 - [Compliance](docs/Compliance.md)
 - [ComplianceResult](docs/ComplianceResult.md)
 - [Compliances](docs/Compliances.md)
 - [CveSearch](docs/CveSearch.md)
 - [CveSearchData](docs/CveSearchData.md)
 - [CveSearchField](docs/CveSearchField.md)
 - [CveSearchImage](docs/CveSearchImage.md)
 - [EcrCredentials](docs/EcrCredentials.md)
 - [Image](docs/Image.md)
 - [ImageLog](docs/ImageLog.md)
 - [ImageLogs](docs/ImageLogs.md)
 - [ImageName](docs/ImageName.md)
 - [ImageRef](docs/ImageRef.md)
 - [Images](docs/Images.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse2001](docs/InlineResponse2001.md)
 - [License](docs/License.md)
 - [LicenseProduct](docs/LicenseProduct.md)
 - [LicenseRequest](docs/LicenseRequest.md)
 - [LicenseRuntime](docs/LicenseRuntime.md)
 - [LicenseScan](docs/LicenseScan.md)
 - [LocalAuthRequest](docs/LocalAuthRequest.md)
 - [PackageSearchData](docs/PackageSearchData.md)
 - [PackageSearchResult](docs/PackageSearchResult.md)
 - [PackageSearchResults](docs/PackageSearchResults.md)
 - [PackageVersion](docs/PackageVersion.md)
 - [Policies](docs/Policies.md)
 - [Policy](docs/Policy.md)
 - [PolicyRule](docs/PolicyRule.md)
 - [PolicyRules](docs/PolicyRules.md)
 - [Registries](docs/Registries.md)
 - [Registry](docs/Registry.md)
 - [ResourceNotFoundError](docs/ResourceNotFoundError.md)
 - [ScanData](docs/ScanData.md)
 - [ScanDatas](docs/ScanDatas.md)
 - [Tag](docs/Tag.md)
 - [TagIDs](docs/TagIDs.md)
 - [TagNames](docs/TagNames.md)
 - [Tags](docs/Tags.md)
 - [TokenRequest](docs/TokenRequest.md)
 - [TokenResponse](docs/TokenResponse.md)
 - [TopCve](docs/TopCve.md)
 - [TopCves](docs/TopCves.md)
 - [TopVulnerableImages](docs/TopVulnerableImages.md)
 - [UnauthorizedError](docs/UnauthorizedError.md)
 - [VulnerabilityCount](docs/VulnerabilityCount.md)
 - [VulnerabilityStats](docs/VulnerabilityStats.md)
 - [VulnerableImage](docs/VulnerableImage.md)
 - [VulnerableImageData](docs/VulnerableImageData.md)


## Documentation For Authorization


## ApiKey

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author

help@layeredinsight.com

